package com.ruoyi.ss.storeApply.service.impl;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.ss.store.domain.Store;
import com.ruoyi.ss.store.domain.StoreQuery;
import com.ruoyi.ss.store.domain.enums.StoreStatus;
import com.ruoyi.ss.store.service.StoreService;
import com.ruoyi.ss.storeApply.domain.StoreApply;
import com.ruoyi.ss.storeApply.domain.StoreApplyQuery;
import com.ruoyi.ss.storeApply.domain.StoreApplyVO;
import com.ruoyi.ss.storeApply.domain.bo.StoreApplyApprovalBO;
import com.ruoyi.ss.storeApply.domain.dto.StoreApplyApprovalDTO;
import com.ruoyi.ss.storeApply.domain.enums.StoreApplyStatus;
import com.ruoyi.ss.storeApply.mapper.StoreApplyMapper;
import com.ruoyi.ss.storeApply.service.StoreApplyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.support.TransactionTemplate;

import java.time.LocalDateTime;
import java.util.List;

/**
 * 店铺审核Service业务层处理
 *
 * @author ruoyi
 * @date 2024-08-03
 */
@Service
public class StoreApplyServiceImpl implements StoreApplyService
{
    @Autowired
    private StoreApplyMapper storeApplyMapper;

    @Autowired
    private TransactionTemplate transactionTemplate;

    @Autowired
    private StoreService storeService;

    /**
     * 查询店铺审核
     *
     * @param id 店铺审核主键
     * @return 店铺审核
     */
    @Override
    public StoreApplyVO selectStoreApplyById(Long id)
    {
        return storeApplyMapper.selectStoreApplyById(id);
    }

    /**
     * 查询店铺审核列表
     *
     * @param storeApply 店铺审核
     * @return 店铺审核
     */
    @Override
    public List<StoreApplyVO> selectStoreApplyList(StoreApplyQuery storeApply)
    {
        return storeApplyMapper.selectStoreApplyList(storeApply);
    }

    /**
     * 新增店铺审核
     *
     * @param storeApply 店铺审核
     * @return 结果
     */
    @Override
    public int insertStoreApply(StoreApply storeApply)
    {
        storeApply.setCreateTime(DateUtils.getNowDate());
        return storeApplyMapper.insertStoreApply(storeApply);
    }

    /**
     * 修改店铺审核
     *
     * @param storeApply 店铺审核
     * @return 结果
     */
    @Override
    public int updateStoreApply(StoreApply storeApply)
    {
        return storeApplyMapper.updateStoreApply(storeApply);
    }

    /**
     * 批量删除店铺审核
     *
     * @param ids 需要删除的店铺审核主键
     * @return 结果
     */
    @Override
    public int deleteStoreApplyByIds(Long[] ids)
    {
        return storeApplyMapper.deleteStoreApplyByIds(ids);
    }

    /**
     * 删除店铺审核信息
     *
     * @param id 店铺审核主键
     * @return 结果
     */
    @Override
    public int deleteStoreApplyById(Long id)
    {
        return storeApplyMapper.deleteStoreApplyById(id);
    }

    @Override
    public int approval(StoreApplyApprovalBO bo) {
        ServiceUtil.assertion(bo == null, "参数错误");

        StoreApplyApprovalDTO dto = bo.getDto();
        ServiceUtil.assertion(dto == null, "原参数不存在");

        StoreApplyVO apply = bo.getApply();
        ServiceUtil.assertion(apply == null, "申请不存在");
        ServiceUtil.assertion(apply.getId() == null, "申请参数有误");

        SysUser verifyUser = bo.getVerifyUser();
        ServiceUtil.assertion(verifyUser == null, "审核人不存在");

        Integer result = transactionTemplate.execute(status -> {
            // 修改状态
            StoreApply data = new StoreApply();
            data.setStatus(dto.getPass() ? StoreApplyStatus.PASS.getStatus() : StoreApplyStatus.REJECT.getStatus());
            data.setVerifyId(verifyUser.getUserId());
            data.setVerifyTime(LocalDateTime.now());
            data.setVerifyRemark(dto.getVerifyRemark());
            StoreApplyQuery query = new StoreApplyQuery();
            query.setId(apply.getId());
            query.setStatus(StoreApplyStatus.WAIT_AUDIT.getStatus());
            int update = this.updateByQuery(data, query);
            ServiceUtil.assertion(update != 1, "当前申请数据发生变化，请刷新后重试");

            if (dto.getPass()) {
                // 通过，应用到设备中
                int applyCount = this.applyToStore(apply);
                ServiceUtil.assertion(applyCount != 1, "应用到店铺失败，请刷新后重试");
            } else {
                // 驳回，店铺修改状态为正常
                Store store = new Store();
                store.setStoreId(apply.getStoreId());
                store.setStatus(StoreStatus.NORMAL.getStatus());
                int storeUpdate = storeService.updateSmStore(store);
                ServiceUtil.assertion(storeUpdate != 1, "店铺状态修改失败，请刷新后重试");
            }

            return update;
        });

        return result == null ? 0 : result;
    }

    /**
     * 应用到设备中
     */
    private int applyToStore(StoreApply apply) {
        Store newData = apply.getNewData();
        if (newData == null) {
            return 0;
        }
        newData.setStoreId(apply.getStoreId());
        newData.setStatus(StoreStatus.NORMAL.getStatus());
        newData.setEnabled(true);
        return storeService.updateSmStore(newData);
    }

    @Override
    public int updateByQuery(StoreApply data, StoreApplyQuery query) {
        if (query == null) {
            return 0;
        }
        return storeApplyMapper.updateByQuery(data, query);
    }

    @Override
    public StoreApplyVO selectOne(StoreApplyQuery query) {
        return storeApplyMapper.selectOne(query);
    }

    @Override
    public int cancel(Long id) {
        StoreApplyVO apply = selectStoreApplyById(id);
        ServiceUtil.assertion(apply == null, "申请不存在");

        Integer result = transactionTemplate.execute(status -> {
            // 修改申请状态
            StoreApply data = new StoreApply();
            data.setStatus(StoreApplyStatus.CANCEL.getStatus());
            StoreApplyQuery query = new StoreApplyQuery();
            query.setId(id);
            query.setStatus(StoreApplyStatus.WAIT_AUDIT.getStatus());
            int update = this.updateByQuery(data, query);
            ServiceUtil.assertion(update != 1, "当前申请数据发生变化，请刷新后重试");

            // 修改店铺状态
            Store storeData = new Store();
            storeData.setStatus(StoreStatus.NORMAL.getStatus());
            StoreQuery storeQuery = new StoreQuery();
            storeQuery.setStoreId(apply.getStoreId());
            int storeUpdate = storeService.updateByQuery(storeData, storeQuery);
            ServiceUtil.assertion(storeUpdate != 1, "店铺状态修改失败，请刷新后重试");

            return update;
        });

        return result == null ? 0 : result;
    }

    @Override
    public int selectCount(StoreApplyQuery query) {
        return storeApplyMapper.selectCount(query);
    }

}
